# Direct Connect ++ client

## Install
On Ubuntu from PPA.
```sh
sudo add-apt-repository ppa:colin-i/ppa
```
Or the *manual installation step* from this link *https://gist.github.com/colin-i/e324e85e0438ed71219673fbcc661da6* \
Install:
```sh
sudo apt-get install dicopp
```
\
On linux distributions, <i>.AppImage</i> file from [releases](https://github.com/colin-i/dico/releases).
\
On Fedora, <i>.rpm</i> file from [releases](https://github.com/colin-i/dico/releases).
```sh
yum install dicopp-*.*.rpm
```
\
From pypi:
```sh
pip3 install dicopp
```
And having the dependencies.

## From source
Using eiskaltdcpp-daemon through json rpc and gtk4 bound with PyGObject.\
With setup.py or the other python setup script.

## [Info](https://github.com/colin-i/dico/blob/master/info.md)

## Donations
The *donations* section is here
*https://gist.github.com/colin-i/e324e85e0438ed71219673fbcc661da6*
